Crate ene_kafka_derive

Crate ene_kafka_derive 

Derive Macros

CloudEvent
Derive the CloudEvent trait for a struct It requires the following attributes:
DeserializeFrom
Derive the DeserializeFrom trait for a struct It relies on the KafkaMessage trait and requires the following attributes:
EventHandler
Derive the EventHandler trait for a struct It requires the following attributes:
KafkaMessage
Derive the KafkaMessage trait for a struct It requires the following attributes: