Derive Macros
- Cloud
Event - Derive the CloudEvent trait for a struct It requires the following attributes:
- Deserialize
From - Derive the DeserializeFrom trait for a struct
It relies on the
KafkaMessagetrait and requires the following attributes: - Event
Handler - Derive the EventHandler trait for a struct It requires the following attributes:
- Kafka
Message - Derive the KafkaMessage trait for a struct It requires the following attributes: